#include <stdio.h>
#include <string.h>
#include <stdbool.h>

#include "states.h"
#include "open_gui.h"

#ifndef PROJ_VERSION
  #define PROJ_VERSION "unknown"
#endif

States currentstate;
char *version = PROJ_VERSION;

void update_state(States state) {
  currentstate = state;
}

int is_arg(int ac, char **argv, char *arg) {
  if (ac < 2) {
    return 0;
  }
  for(int x=1; x < ac; x++) {
    if (0 == strcmp(argv[x], arg)) {
      return x;  // return position of arg
    }
  }
  return 0;  // arg not present
}

void display_version(bool is_debug) {
  if(is_debug) printf("v%s-beta\n", version);
  else printf("v%s\n", version);
}

void display_about(bool is_debug) {
  printf("Melon VPN\n");
  display_version(is_debug);
  printf("Copyright OnPointCoding\n");
  printf("https://software.onpointcoding.net\n");
  printf("OnPointCoding.net\n");
  printf("Author: MrMelon54\n");
  printf("Artist: MrMelon54\n");
}

void display_help(bool is_debug) {
  printf("Melon VPN Help\n");
  printf("-h, --help  Display this help message\n");
  printf("--about      About this program\n");
}

int main (int argc, char **argv) {
  int status;
  currentstate = DISCONNECTED;

  bool is_debug = is_arg(argc, argv, "--debug");

  if(is_arg(argc, argv, "--help") || is_arg(argc, argv, "-h")) {
    display_help(is_debug);
    return 0;
  }

  if(is_arg(argc, argv, "--version") || is_arg(argc, argv, "-v")) {
    display_version(is_debug);
    return 0;
  }

  if(is_arg(argc, argv, "--about")) {
    display_about(is_debug);
    return 0;
  }

  if(is_arg(argc, argv, "--gui")) {
    open_gui(argc, argv, is_debug);
    return 0;
  }

  return status;
}
